@@ -23,6 +23,9 @@ class Game:
         self.current_start_attempts = 0
 
     def __dice_generator(self):
+        """
+        Will update self.current_dice with a new random number on the dice
+        """
         self.current_dice = np.random.randint(1, 6 + 1)
 
     def get_pieces(self, seen_from=None):
@@ -47,7 +50,10 @@ class Game:
         return pieces, enemy_pieces
 
     def __add_to_hist(self):
-        pieces = self.get_pieces()
+        """
+        Adds the state of the game to the history
+        """
+        pieces, _ = self.get_pieces()
         self.hist.append([pieces, self.current_dice, self.current_player+1, self.round])
 
     def reset(self):
@@ -77,6 +83,12 @@ class Game:
         return dice, move_pieces, player_pieces, enemy_pieces, player_is_a_winner, there_is_a_winner
 
     def __set_enemy_pieces(self, player_idx, enemy_pieces):
+        """
+        Will set the enemy pieces to the pieces given in enemy_pieces
+
+        :param player_idx: The player the enemys are seen from
+        :param enemy_pieces: The pieces to update
+        """
         # Go throng the enemy's and set the changes in there piece
         for e_i, e in enumerate(self.enemys_order[player_idx]):
             self.players[e].set_pieces(enemy_pieces[e_i])
@@ -105,6 +117,9 @@ class Game:
         return obs, self.current_player + 1
 
     def __count_player(self):
+        """
+        Updates the current player and the round if the current player was the last player
+        """
         # Count up the player
         self.current_player += 1
         # If the count is over 3 then reset to player 0 and count up the round
@@ -177,6 +192,31 @@ class Game:
         """
         return self.hist
 
+    def get_piece_hist(self, mode=0):
+        """
+        Will return the how the pieces was recorded during the game.
+        :param mode: 0: All recorded pieces is returnt. 1: Only if a change is done there will be a new set of pieces.
+        2: Only unique set of pieces (order is preserved)
+        :return piece_hist: List of sets of pieces
+        """
+        piece_hist = [self.hist[0][0]]
+        for h in self.hist[1:]:
+            pieces = h[0]
+
+            add_to_hist = False
+            if mode == 0:
+                add_to_hist = True
+            if mode == 1:
+                if pieces != piece_hist[-1]:
+                    add_to_hist = True
+            if mode == 2:
+                if pieces not in piece_hist:
+                    add_to_hist = True
+
+            if add_to_hist:
+                piece_hist.append(pieces)
+        return piece_hist
+
     def render_environment(self):
         """
         Will render the last record in the history
